#!/usr/bin/perl -w
# ================================================================================================
# Remote FTP Log Retriever - Downloads files from an FTP server to a local folder on the web server.
# Copyright (C) 2009 Synthetic
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# ================================================================================================
# 
# This Perl script was designed in mind for 3rd party gaming stats programs on web hosts/servers that don't allow
# use of the FTP extensions for PHP to retrieve log files on a remote game server. All it does is copies all the files found in the specified
# directory on a remote FTP server to a local folder on the web server running this script. For example from your game server log folder 
# to a folder on your web server that your stats package can then easily access to generate stats from. It also offers the ability to delete 
#  the remote files after transfer.
#
# ===================================
# INSTALLATION
# ===================================
# - Copy this file to a location outsite of your public www/html folder or in some cases it will
#   have to be located in your cgi-bin folder. Make sure to CHMOD this file to 755.
# 
# - Set the variables to your liking.
#
# - If using this for downloading log files from your game server for your stats program, be sure
#   to setup a CRON job for this as well! Generally about 5-10 minutes or longer (depending on how
#   many logs need to be retrieved) before the CRON job for the stats program. This will allow
#   the logs to be ready for use when it fires off.
#
# ===================================
# SETTINGS
# ===================================
# $host
# - This is where you enter the IP of your sever.
#
# $port
# - This is where you enter the port used by your server to recieve FTP connections. It is almost
#   always 21 and you won't need to change it. 
#
# $user | $pass
# - These are the username and password you use to connect via FTP to your server.
#
# $passive
# - If you are behind a firewall and/or have trouble connecting to your server, try enabling this.
#
# $log_path
# - This is the path to the directory on the remote server that has the files you want to transfer.
#
# $save_path
# - This is the path to the local directory where you want the remotely recieved files saved to on the 
#   server running this script.
# 
# $del_log
# - Enables or disables deleting remote logs after transfer. 0 = Don't delete | 1 = Delete
#
# $debug
# - Enables or disables simple current action reports. 0 = Don't show | 1 = Show

$host      = "10.0.0.1";
$port      = "21";
$user      = "username";
$pass      = "password";
$passive   = "1";
$log_path  = "/dod/logs";
$save_path = "/home/users/a/htdocs/pslogs";
$del_log   = "1";
$debug     = 0;
# ================================================================================================

use Net::FTP;

# If debug is enabled show current action.
if($debug)
{
	print "Content-type: text/html\n\n";
	print "Getting log files...<br />\n";
}

$ftp = Net::FTP -> new ($host,Port=>$port,Passive=>$passive,Debug=>0) or die "Could not connect to server!\n";
$ftp -> login($user,$pass) or die "Username or password is incorrect!\n";
$ftp -> cwd($log_path) or die "Could not change to or find this directory!\n";
$ftp -> binary() or die "Could not switch to binary mode!\n";
@files=$ftp->ls() or die "COuld not read contents of directory!\n";

# Make sure there are logs to download. If not, exit.
if(@files == 0) {
	# If debug is enabled show current action.
	if($debug)
	{
		print "No log files found so quitting!<br />\n";
	}
	exit 0;
}

# Get all files. This may take some time if there are alot! Also, delete ones downloaded.
foreach(@files) {
	if($debug)
	{
		print "Attempting to get: $_<br />\n";
		print "Saving to/as: $save_path/$_<br />\n";
	}
	$ftp -> get($_,"$save_path/$_") or die "File could not be downloaded!\n";
	if($del_log)
	{
		print "Attempting to delete: $_<br />\n";
		$ftp -> delete($_) or die "File could not be deleted!\n";
	}
}

# Kill off connection and report process has finished.
$ftp -> quit;

if($debug)
{
	print "Finished!\n";
}

# If connection didn't close, let's drink some lead paint!
$ftp->quit or die "Connection would not close!";
      
exit;